local require = GLOBAL.require
local SpawnPrefab = GLOBAL.SpawnPrefab
--
require "class"

local Ingredient = GLOBAL.Ingredient
local RECIPETABS = GLOBAL.RECIPETABS
local STRINGS = GLOBAL.STRINGS
local ACTIONS = GLOBAL.ACTIONS
local Action = GLOBAL.Action
        TECH = GLOBAL.TECH

GLOBAL.STRINGS.NAMES.EMERLING = "Emerling"		
GLOBAL.STRINGS.RECIPE_DESC.EMERLING = "Create your emerald guardian!"
GLOBAL.STRINGS.CHARACTERS.GENERIC.DESCRIBE.EMERLING = "My very own bodyguard!"

PrefabFiles = {

	"rock_emerald",
	"emerald",
	"emerald_sword",
	"emerald_crown",
	"emerald_armor",
	"emerald_flower",
	"imp",
	"emerling",
}

local assets=
{
    Asset("ATLAS", "images/inventoryimages/emerald.xml"),
    Asset("IMAGE", "images/inventoryimages/emerald.tex"),
	
	Asset("ATLAS", "images/inventoryimages/emerald_sword.xml"),
    Asset("IMAGE", "images/inventoryimages/emerald_sword.tex"),
	
	Asset("ATLAS", "images/inventoryimages/emerald_crown.xml"),
    Asset("IMAGE", "images/inventoryimages/emerald_crown.tex"),
	
	Asset("ATLAS", "images/inventoryimages/emerald_armor.xml"),
    Asset("IMAGE", "images/inventoryimages/emerald_armor.tex"),
	
	Asset("ATLAS", "images/inventoryimages/emerald_flower.xml"),
	Asset("IMAGE", "images/inventoryimages/emerald_flower.tex"),
	
	Asset("ATLAS", "images/inventoryimages/emerling.xml"),
	Asset("IMAGE", "images/inventoryimages/emerling.tex"),	
	
}

AddMinimapAtlas("images/inventoryimages/emerald.xml")
--AddMinimapAtlas("images/inventoryimages/emerald_flower.xml")
--AddMinimapAtlas("images/inventoryimages/emerald_sword.xml")
--AddMinimapAtlas("images/inventoryimages/emerald_armor.xml")
--AddMinimapAtlas("images/inventoryimages/emerald_crown.xml")
AddMinimapAtlas("images/inventoryimages/emerling.xml")


local emerald = Ingredient( "emerald", 25)
emerald.atlas = "images/inventoryimages/emerald.xml"

local emerald_swordrecipe = Recipe( "emerald_sword", { emerald }, RECIPETABS.WAR, {SCIENCE = 2} )
emerald_swordrecipe.atlas = "images/inventoryimages/emerald_sword.xml"

local emerald_crownrecipe = Recipe( "emerald_crown", { emerald }, RECIPETABS.DRESS, {SCIENCE = 2} )
emerald_crownrecipe.atlas = "images/inventoryimages/emerald_crown.xml"

local emerald_armorrecipe = Recipe( "emerald_armor", { emerald }, RECIPETABS.DRESS, {SCIENCE = 2} )
emerald_armorrecipe.atlas = "images/inventoryimages/emerald_armor.xml"

local emerlingrecipe = GLOBAL.Recipe( ("emerling"), { emerald, Ingredient("slurtleslime", 10) }, RECIPETABS.WAR,  {SCIENCE = 2} )
emerlingrecipe.atlas = "images/inventoryimages/emerling.xml"
	   
function lootdropperpostinit(inst)

	inst.GenerateLoot = function(self)
    local loots = {}
    
    if self.numrandomloot and math.random() <= (self.chancerandomloot or 1) then
		for k = 1, self.numrandomloot do
		    local loot = self:PickRandomLoot()
		    if loot then
			    table.insert(loots, loot)
			end
		end
	end
    
    if self.chanceloot then
		for k,v in pairs(self.chanceloot) do
			if math.random() < v.chance then
				table.insert(loots, v.prefab)
				self.droppingchanceloot = true
			end
		end
	end

    if self.chanceloottable then
    	local loot_table = GLOBAL.LootTables[self.chanceloottable]
    	if loot_table then
    		for i, entry in ipairs(loot_table) do
    			local prefab = entry[1]
    			local chance = entry[2]    			
				if math.random() <= chance then
					table.insert(loots, prefab)
					self.droppingchanceloot = true
				end
			end
		end
	end

	if not self.droppingchanceloot and self.ifnotchanceloot then
		self.inst:PushEvent("ifnotchanceloot")
		for k,v in pairs(self.ifnotchanceloot) do
			table.insert(loots, v.prefab)
		end
	end


    
    if self.loot then
		for k,v in ipairs(self.loot) do
			table.insert(loots, v)
		end
	end
	
	local recipe = GLOBAL.GetRecipe(self.inst.prefab)

	if recipe and not self.inst.components.norecipelootdrop then
	

		
		local percent = 1

		if self.inst.components.finiteuses then
			percent = self.inst.components.finiteuses:GetPercent()
		end

		for k,v in ipairs(recipe.ingredients) do
			local amt = math.ceil( (v.amount * TUNING.HAMMER_LOOT_PERCENT) * percent)
			for n = 1, amt do
				table.insert(loots, v.type)
			end
		end
	end
    
    return loots

    end


end	   
	   
local function Emerling( inst )

	inst:DoTaskInTime( 0, function() 
		local controls = inst.HUD.controls
		local Emerling_Health = require "widgets/emerling_health"
		controls.petStatus = controls:AddChild(Emerling_Health(inst))
		controls.petStatus:SetPosition(0, -250, 0)
	end)

end	   

AddSimPostInit( Emerling )	  

AddComponentPostInit("lootdropper", lootdropperpostinit)
	   
function HF_addtradablecomponenttoprefab(inst)
	if not inst.components.tradable then
		inst:AddComponent("tradable")
	end
end	 

ACTIONS.GIVE.priority = 4

AddPrefabPostInit("emerald", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("emerald_sword", HF_addtradablecomponenttoprefab)  -- work only with changed action priority.
AddPrefabPostInit("emerald_crown", HF_addtradablecomponenttoprefab)  -- working.
AddPrefabPostInit("emerald_armor", HF_addtradablecomponenttoprefab)  -- working.
AddPrefabPostInit("emerald_crown", HF_addtradablecomponenttoprefab)  -- working.

AddPrefabPostInit("axe", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("goldenaxe", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("pickaxe", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("goldenpickaxe", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("shovel", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("goldenshovel", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("hammer", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("pitchfork", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("multitool_axe_pickaxe", HF_addtradablecomponenttoprefab)

AddPrefabPostInit("grass_umbrella", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("umbrella", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("torch", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("bugnet", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("fishingrod", HF_addtradablecomponenttoprefab)

AddPrefabPostInit("spear", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("hambat", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("tentaclespike", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("ruins_bat", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("nightsword", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("boomerang", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("cane", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("batbat", HF_addtradablecomponenttoprefab)

AddPrefabPostInit("armorgrass", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("armorwood", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("armormarble", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("armor_sanity", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("armorsnurtleshell", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("armorslurper", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("armorruins", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("sweatervest", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("trunkvest_summer", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("trunkvest_winter", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("reflectivevest", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("raincoat", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("rain_hat", HF_addtradablecomponenttoprefab)

AddPrefabPostInit("lighter", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("nightstick", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("lucy", HF_addtradablecomponenttoprefab)

AddPrefabPostInit("spear_wathgrithr", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("beargervest", HF_addtradablecomponenttoprefab)
AddPrefabPostInit("armordragonfly", HF_addtradablecomponenttoprefab)