local emerald_flower_assets =
{
     Asset("ANIM", "anim/emerald_flower.zip"),	 
--	 Asset("IMAGE", "images/inventoryimages/emerald_flower.tex"),
	 Asset("SOUND", "sound/common.fsb"),
}

local prefabs =
{
	"emerald",
	"emerald_flower",
	"imp",
}

SetSharedLootTable( 'rock_flower',
{

    {'emerald',   1.0},
    {'emerald',   1.0},
    {'emerald',   0.5},
	
	{'imp',   1.0},
	{'imp',   1.0},
	{'imp',   1.0},
	{'imp',   1.0},
	{'imp',   0.4},	
    {'imp',   0.2},	

})


local function dig_up_stump(inst)
	inst.components.lootdropper:SpawnLootPrefab("emerald")
	inst:Remove()
end

local function makestump(inst)
    inst:RemoveComponent("workable")
	RemovePhysicsColliders(inst) 
	inst:AddTag("stump")
    
    inst:AddComponent("workable")
    inst.components.workable:SetWorkAction(ACTIONS.DIG)
    inst.components.workable:SetOnFinishCallback(dig_up_stump)
	inst.components.workable:SetWorkLeft(1)
	inst.AnimState:PlayAnimation("idle_stump")
	inst.AnimState:ClearBloomEffectHandle()

	inst.Light:Enable(false)	
end

local function onsave(inst, data)

    if inst:HasTag("stump") then
        data.stump = true
    end
end
        
local function onload(inst, data)

    if data then
        	makestump(inst)
    end
end      

local function workcallback(inst, worker, workleft)
	local pt = Point(inst.Transform:GetWorldPosition())
    inst.SoundEmitter:PlaySound("dontstarve/creatures/smallbird/egg_hatch_crack")          
	if workleft <= 0 then
		inst.SoundEmitter:PlaySound("dontstarve/creatures/slurtle/explode")
		makestump(inst)
	    
        inst.AnimState:PlayAnimation("fall")

		inst.components.lootdropper:DropLoot(pt)
		inst.AnimState:PushAnimation("idle_stump")

	else			
		inst.AnimState:PlayAnimation("chop")
		inst.AnimState:PushAnimation("idle_loop", true)
	end
end

local function flower_fn(Sim)
	local inst = CreateEntity()
	local trans = inst.entity:AddTransform()
	local anim = inst.entity:AddAnimState()
	inst.entity:AddSoundEmitter()

	local light = inst.entity:AddLight()
    inst.Light:Enable(true)
	inst.Light:SetRadius(1.6)
    inst.Light:SetFalloff(0.7)
    inst.Light:SetIntensity(.9)
    inst.Light:SetColour(32/255,229/255,153/255)
	
	MakeObstaclePhysics(inst, 1.)
	
--	inst.entity:AddMiniMapEntity()	
--	inst.MiniMapEntity:SetIcon( "emerald_flower.tex" )	

	inst:AddComponent("lootdropper") 
	
	inst:AddComponent("workable")
	inst.components.workable:SetWorkAction(ACTIONS.CHOP)
	inst.components.workable:SetWorkLeft(10)
	inst.components.workable:SetOnWorkCallback(workcallback)

	inst:AddComponent("inspectable")
	MakeSnowCovered(inst, .01)   

	inst.OnSave = onsave
	inst.OnLoad = onload
	return inst
end

local function emerald_flower_fn(Sim)
	local inst = flower_fn(Sim)
	inst.AnimState:SetBank("mushroom_tree_med")
	inst.AnimState:SetBuild("emerald_flower")
	inst.AnimState:PlayAnimation("idle_loop", true)
    inst.AnimState:SetTime(math.random()*2) 

	inst.components.lootdropper:SetChanceLootTable('rock_flower')

	return inst
end

STRINGS.NAMES.EMERALD_FLOWER = "Emerald flower"
STRINGS.CHARACTERS.GENERIC.DESCRIBE.EMERALD_FLOWER = {	
	"This is a very strange flower.",
}

return Prefab("cave/objects/emerald_flower", emerald_flower_fn, emerald_flower_assets, prefabs)

